@@ -1,4 +1,4 @@
-require 'spec_helper'
+# frozen_string_literal: true
 
 # If this file is tested alone (rspec path-to-this-file), then there will be an error about
 # constants not being intilialized. This is due to the Dynamic Finders.
