@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 describe WPScan::Vulnerability do
-  subject(:vuln)   { described_class.new(title, references) }
+  subject(:vuln)   { described_class.new(title, references: references) }
   let(:title)      { 'Test Vuln' }
   let(:references) { {} }
 
