@@ -4,15 +4,22 @@ shared_examples 'WordPress::CustomDirectories' do
   let(:fixtures) { super().join('custom_directories') }
 
   describe '#content_dir' do
+    # Stub the error_404_res to make it easier to test
+    before { stub_request(:get, ERROR_404_URL_PATTERN) }
+
     {
       default: 'wp-content', https: 'wp-content', custom_w_spaces: 'custom content spaces',
       relative_one: 'wp-content', relative_two: 'wp-content', cache: 'wp-content',
       in_raw_js: 'wp-content', in_raw_js_escaped: 'wp-content', with_sub_dir: 'app',
-      relative_two_sub_dir: 'cms/wp-content', in_meta_content: 'wp-content'
+      relative_two_sub_dir: 'cms/wp-content', in_meta_content: 'wp-content',
+      themes_path_plugin_folder: 'wp-content', simple_link: nil
     }.each do |file, expected|
       it "returns #{expected} for #{file}.html" do
         stub_request(:get, target.url).to_return(body: File.read(fixtures.join("#{file}.html")))
 
+        # For cases where the expected is nil
+        allow(target).to receive(:default_content_dir_exists?).and_return(false)
+
         expect(target.content_dir).to eql expected
       end
     end
@@ -41,36 +48,26 @@ shared_examples 'WordPress::CustomDirectories' do
       end
     end
 
-    context 'when not found via the homepage' do
-      before { stub_request(:get, target.url).to_return(body: '') }
+    context 'when not found via the homepage or 404' do
+      before do
+        stub_request(:get, target.url)
+
+        expect(target).to receive(:default_content_dir_exists?).and_return(dir_exist)
+      end
+
+      context 'when default dir does not exist' do
+        let(:dir_exist) { false }
 
-      context 'when detection mode is passive' do
         it 'returns nil' do
-          expect(target).not_to receive(:default_content_dir_exist?)
-
-          expect(target.content_dir(:passive)).to eql nil
+          expect(target.content_dir).to eql nil
         end
       end
 
-      context 'when detection mode is mixed or aggressive' do
-        before { expect(target).to receive(:default_content_dir_exists?).and_return(dir_exist) }
+      context 'when default dir exists' do
+        let(:dir_exist) { true }
 
-        %i[mixed aggressive].each do |mode|
-          context 'when default content dir exists' do
-            let(:dir_exist) { true }
-
-            it 'returns wp-content' do
-              expect(target.content_dir(mode)).to eql 'wp-content'
-            end
-          end
-
-          context 'when default content dir does not exist' do
-            let(:dir_exist) { false }
-
-            it 'returns nil' do
-              expect(target.content_dir(mode)).to eql nil
-            end
-          end
+        it 'returns wp-content' do
+          expect(target.content_dir).to eql 'wp-content'
         end
       end
     end
@@ -98,7 +95,7 @@ shared_examples 'WordPress::CustomDirectories' do
   end
 
   describe '#content_dir=, #plugins_dir=' do
-    ['wp-content', 'wp-custom'].each do |dir|
+    %w[wp-content wp-custom].each do |dir|
       context "when content_dir = #{dir} and no plugins_dir" do
         before { target.content_dir = dir }
 
@@ -129,6 +126,9 @@ shared_examples 'WordPress::CustomDirectories' do
   end
 
   describe '#sub_dir' do
+    # Stub the error_404_res to make it easier to test
+    before { stub_request(:get, ERROR_404_URL_PATTERN) }
+
     { default: false, with_sub_dir: 'wp', relative_two_sub_dir: 'cms' }.each do |file, expected|
       it "returns #{expected} for #{file}.html" do
         fixture = File.join(fixtures, "#{file}.html")
@@ -138,6 +138,35 @@ shared_examples 'WordPress::CustomDirectories' do
         expect(target.sub_dir).to eql expected
       end
     end
+
+    context 'when no sub_dir detected' do
+      it 'only checks the in_scope_uris once' do
+        stub_request(:get, target.url).to_return(body: File.read(File.join(fixtures, 'default.html')))
+
+        expect(target.sub_dir).to eql false
+
+        expect(target).to_not receive(:in_scope_uris)
+        expect(target.sub_dir).to eql false
+      end
+    end
+
+    context 'when a lot of irrelevant urls' do
+      let(:body) do
+        Array.new(250) do |i|
+          "<a href='#{subject.url}#{i}.html>Link</a><img src='#subject.{url}img-#{i}.png'/>"
+        end.join("\n")
+      end
+
+      it 'should not take a while to detect the sub_dir' do
+        stub_request(:get, target.url).to_return(body: body)
+
+        time_start = Time.now
+        expect(target.sub_dir).to eql false
+        time_end = Time.now
+
+        expect(time_end - time_start).to be < 1
+      end
+    end
   end
 
   describe '#url' do
